@@ -1,6 +1,6 @@
 /* NM FSM, common bits */
 
-/* (C) 2020 by sysmocom - s.m.f.c. GmbH <info@sysmocom.de>
+/* (C) 2020 by sysmocom - s.f.m.c. GmbH <info@sysmocom.de>
  * Author: Pau Espin Pedrol <pespin@sysmocom.de>
  *
  * All Rights Reserved
@@ -25,15 +25,21 @@
 
 const struct value_string nm_fsm_event_names[] = {
 	{ NM_EV_SW_ACT, "SW_ACT" },
+	{ NM_EV_RX_SETATTR, "RX_SETATTR" },
+	{ NM_EV_RX_OPSTART, "RX_OPSTART" },
 	{ NM_EV_OPSTART_ACK, "OPSTART_ACK" },
 	{ NM_EV_OPSTART_NACK, "OPSTART_NACK" },
+	{ NM_EV_SHUTDOWN_START, "SHUTDOWN_START" },
+	{ NM_EV_SHUTDOWN_FINISH, "SHUTDOWN_FINISH" },
+	{ NM_EV_OML_UP, "OML_UP" },
 	{ NM_EV_RSL_UP, "RSL_UP" },
 	{ NM_EV_RSL_DOWN, "RSL_DOWN" },
 	{ NM_EV_PHYLINK_UP, "PHYLINK_UP" },
 	{ NM_EV_PHYLINK_DOWN, "PHYLINK_DOWN" },
 	{ NM_EV_DISABLE, "DISABLE" },
-	{ NM_EV_BBTRANSC_INSTALLED, "BBTRANSC_INSTALLED" },
 	{ NM_EV_BBTRANSC_ENABLED, "BBTRANSC_ENABLED" },
 	{ NM_EV_BBTRANSC_DISABLED, "BBTRANSC_DISABLED" },
+	{ NM_EV_RCARRIER_ENABLED, "RCARRIER_ENABLED" },
+	{ NM_EV_RCARRIER_DISABLED, "RCARRIER_DISABLED" },
 	{ 0, NULL }
 };
