@@ -53,6 +53,8 @@ static int avail_lai = 0, avail_nse = 0, avail_cell = 0, avail_nsvc[2] = {0, 0};
 
 static const char *sapi_string[] = {
 	[PCU_IF_SAPI_RACH] =	"RACH",
+	[PCU_IF_SAPI_AGCH] =	"AGCH",
+	[PCU_IF_SAPI_PCH] =	"PCH",
 	[PCU_IF_SAPI_BCCH] =	"BCCH",
 	[PCU_IF_SAPI_PDTCH] =	"PDTCH",
 	[PCU_IF_SAPI_PRACH] =	"PRACH",
@@ -230,25 +232,6 @@ static void info_ind_fill_trx(struct gsm_pcu_if_info_trx *trx_info,
 	}
 }
 
-static enum gsm_pcuif_bts_model bts_model_from_variant(enum gsm_bts_type_variant variant)
-{
-	switch (variant) {
-	case BTS_OSMO_LITECELL15:
-		return PCU_IF_BTS_MODEL_LC15;
-	case BTS_OSMO_OC2G:
-		return PCU_IF_BTS_MODEL_OC2G;
-	case BTS_OSMO_OCTPHY:
-		return PCU_IF_BTS_MODEL_OCTPHY;
-	case BTS_OSMO_SYSMO:
-		return PCU_IF_BTS_MODEL_SYSMO;
-	case BTS_OSMO_TRX:
-	case BTS_OSMO_VIRTUAL:
-		return PCU_IF_BTS_MODEL_TRX;
-	default:
-		return PCU_IF_BTS_MODEL_UNSPEC;
-	}
-}
-
 int pcu_tx_info_ind(void)
 {
 	struct msgb *msg;
@@ -281,7 +264,7 @@ int pcu_tx_info_ind(void)
 		LOGP(DPCU, LOGL_INFO, "BTS is down\n");
 
 	if (pcu_direct)
-		info_ind->flags |= PCU_IF_FLAG_DIRECT_PHY;
+		info_ind->flags |= PCU_IF_FLAG_SYSMO;
 
 	info_ind->bsic = bts->bsic;
 	/* RAI */
@@ -377,8 +360,6 @@ int pcu_tx_info_ind(void)
 		info_ind_fill_trx(&info_ind->trx[trx->nr], trx);
 	}
 
-	info_ind->bts_model = bts_model_from_variant(bts->variant);
-
 	return pcu_sock_send(msg);
 }
 
